" )
@@ -891,7 +905,7 @@ $.widget( "ui.dialog", {
var overlays = this.document.data( "ui-dialog-overlays" ) - 1;
if ( !overlays ) {
- this._off( this.document, "focusin" );
+ this.document.off( "focusin.ui-dialog" );
this.document.removeData( "ui-dialog-overlays" );
} else {
this.document.data( "ui-dialog-overlays", overlays );
@@ -929,4 +943,4 @@ if ( $.uiBackCompat !== false ) {
return $.ui.dialog;
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/effect-blind.js b/src/js/_enqueues/vendor/jquery/ui/effect-blind.js
index 6ab63fa1d0..6a27d2ef6c 100644
--- a/src/js/_enqueues/vendor/jquery/ui/effect-blind.js
+++ b/src/js/_enqueues/vendor/jquery/ui/effect-blind.js
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Effects Blind 1.12.1
+ * jQuery UI Effects Blind 1.13.0-rc.2
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -14,6 +14,8 @@
//>>demos: http://jqueryui.com/effect/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -26,7 +28,8 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.effects.define( "blind", "hide", function( options, done ) {
var map = {
@@ -66,4 +69,4 @@ return $.effects.define( "blind", "hide", function( options, done ) {
} );
} );
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/effect-bounce.js b/src/js/_enqueues/vendor/jquery/ui/effect-bounce.js
index 00ff5b2235..0f07eed039 100644
--- a/src/js/_enqueues/vendor/jquery/ui/effect-bounce.js
+++ b/src/js/_enqueues/vendor/jquery/ui/effect-bounce.js
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Effects Bounce 1.12.1
+ * jQuery UI Effects Bounce 1.13.0-rc.2
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -14,6 +14,8 @@
//>>demos: http://jqueryui.com/effect/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -26,7 +28,8 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.effects.define( "bounce", function( options, done ) {
var upAnim, downAnim, refValue,
@@ -106,4 +109,4 @@ return $.effects.define( "bounce", function( options, done ) {
$.effects.unshift( element, queuelen, anims + 1 );
} );
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/effect-clip.js b/src/js/_enqueues/vendor/jquery/ui/effect-clip.js
index bdeaeb2607..b08ae48a24 100644
--- a/src/js/_enqueues/vendor/jquery/ui/effect-clip.js
+++ b/src/js/_enqueues/vendor/jquery/ui/effect-clip.js
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Effects Clip 1.12.1
+ * jQuery UI Effects Clip 1.13.0-rc.2
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -14,6 +14,8 @@
//>>demos: http://jqueryui.com/effect/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -26,7 +28,8 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.effects.define( "clip", "hide", function( options, done ) {
var start,
@@ -61,4 +64,4 @@ return $.effects.define( "clip", "hide", function( options, done ) {
} );
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/effect-drop.js b/src/js/_enqueues/vendor/jquery/ui/effect-drop.js
index b38fe5ff60..9976a93360 100644
--- a/src/js/_enqueues/vendor/jquery/ui/effect-drop.js
+++ b/src/js/_enqueues/vendor/jquery/ui/effect-drop.js
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Effects Drop 1.12.1
+ * jQuery UI Effects Drop 1.13.0-rc.2
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -14,6 +14,8 @@
//>>demos: http://jqueryui.com/effect/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -26,7 +28,8 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.effects.define( "drop", "hide", function( options, done ) {
@@ -65,4 +68,4 @@ return $.effects.define( "drop", "hide", function( options, done ) {
} );
} );
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/effect-explode.js b/src/js/_enqueues/vendor/jquery/ui/effect-explode.js
index 89a2c83f7f..8ce41aa221 100644
--- a/src/js/_enqueues/vendor/jquery/ui/effect-explode.js
+++ b/src/js/_enqueues/vendor/jquery/ui/effect-explode.js
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Effects Explode 1.12.1
+ * jQuery UI Effects Explode 1.13.0-rc.2
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -9,13 +9,15 @@
//>>label: Explode Effect
//>>group: Effects
-// jscs:disable maximumLineLength
+/* eslint-disable max-len */
//>>description: Explodes an element in all directions into n pieces. Implodes an element to its original wholeness.
-// jscs:enable maximumLineLength
+/* eslint-enable max-len */
//>>docs: http://api.jqueryui.com/explode-effect/
//>>demos: http://jqueryui.com/effect/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -28,7 +30,8 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.effects.define( "explode", "hide", function( options, done ) {
@@ -107,4 +110,4 @@ return $.effects.define( "explode", "hide", function( options, done ) {
}
} );
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/effect-fade.js b/src/js/_enqueues/vendor/jquery/ui/effect-fade.js
index 8ea555204a..6b3aac99cf 100644
--- a/src/js/_enqueues/vendor/jquery/ui/effect-fade.js
+++ b/src/js/_enqueues/vendor/jquery/ui/effect-fade.js
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Effects Fade 1.12.1
+ * jQuery UI Effects Fade 1.13.0-rc.2
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -14,6 +14,8 @@
//>>demos: http://jqueryui.com/effect/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -26,7 +28,8 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.effects.define( "fade", "toggle", function( options, done ) {
var show = options.mode === "show";
@@ -43,4 +46,4 @@ return $.effects.define( "fade", "toggle", function( options, done ) {
} );
} );
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/effect-fold.js b/src/js/_enqueues/vendor/jquery/ui/effect-fold.js
index 357689954e..982aa98bd6 100644
--- a/src/js/_enqueues/vendor/jquery/ui/effect-fold.js
+++ b/src/js/_enqueues/vendor/jquery/ui/effect-fold.js
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Effects Fold 1.12.1
+ * jQuery UI Effects Fold 1.13.0-rc.2
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -14,6 +14,8 @@
//>>demos: http://jqueryui.com/effect/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -26,7 +28,8 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.effects.define( "fold", "hide", function( options, done ) {
@@ -85,4 +88,4 @@ return $.effects.define( "fold", "hide", function( options, done ) {
$.effects.unshift( element, queuelen, 4 );
} );
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/effect-highlight.js b/src/js/_enqueues/vendor/jquery/ui/effect-highlight.js
index 0f48bf33cb..21e13d45ec 100644
--- a/src/js/_enqueues/vendor/jquery/ui/effect-highlight.js
+++ b/src/js/_enqueues/vendor/jquery/ui/effect-highlight.js
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Effects Highlight 1.12.1
+ * jQuery UI Effects Highlight 1.13.0-rc.2
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -14,6 +14,8 @@
//>>demos: http://jqueryui.com/effect/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -26,7 +28,8 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.effects.define( "highlight", "show", function( options, done ) {
var element = $( this ),
@@ -53,4 +56,4 @@ return $.effects.define( "highlight", "show", function( options, done ) {
} );
} );
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/effect-puff.js b/src/js/_enqueues/vendor/jquery/ui/effect-puff.js
index 51d5ab43ba..28f4aa7fa9 100644
--- a/src/js/_enqueues/vendor/jquery/ui/effect-puff.js
+++ b/src/js/_enqueues/vendor/jquery/ui/effect-puff.js
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Effects Puff 1.12.1
+ * jQuery UI Effects Puff 1.13.0-rc.2
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -14,6 +14,8 @@
//>>demos: http://jqueryui.com/effect/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -27,7 +29,8 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.effects.define( "puff", "hide", function( options, done ) {
var newOptions = $.extend( true, {}, options, {
@@ -38,4 +41,4 @@ return $.effects.define( "puff", "hide", function( options, done ) {
$.effects.effect.scale.call( this, newOptions, done );
} );
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/effect-pulsate.js b/src/js/_enqueues/vendor/jquery/ui/effect-pulsate.js
index 065025815a..b236c38f14 100644
--- a/src/js/_enqueues/vendor/jquery/ui/effect-pulsate.js
+++ b/src/js/_enqueues/vendor/jquery/ui/effect-pulsate.js
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Effects Pulsate 1.12.1
+ * jQuery UI Effects Pulsate 1.13.0-rc.2
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -14,6 +14,8 @@
//>>demos: http://jqueryui.com/effect/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -26,7 +28,8 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.effects.define( "pulsate", "show", function( options, done ) {
var element = $( this ),
@@ -60,4 +63,4 @@ return $.effects.define( "pulsate", "show", function( options, done ) {
$.effects.unshift( element, queuelen, anims + 1 );
} );
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/effect-scale.js b/src/js/_enqueues/vendor/jquery/ui/effect-scale.js
index 04daabfe6c..68ce95abcb 100644
--- a/src/js/_enqueues/vendor/jquery/ui/effect-scale.js
+++ b/src/js/_enqueues/vendor/jquery/ui/effect-scale.js
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Effects Scale 1.12.1
+ * jQuery UI Effects Scale 1.13.0-rc.2
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -14,6 +14,8 @@
//>>demos: http://jqueryui.com/effect/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -27,7 +29,8 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.effects.define( "scale", function( options, done ) {
@@ -52,4 +55,4 @@ return $.effects.define( "scale", function( options, done ) {
$.effects.effect.size.call( this, newOptions, done );
} );
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/effect-shake.js b/src/js/_enqueues/vendor/jquery/ui/effect-shake.js
index a59e1a8899..568eca5e86 100644
--- a/src/js/_enqueues/vendor/jquery/ui/effect-shake.js
+++ b/src/js/_enqueues/vendor/jquery/ui/effect-shake.js
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Effects Shake 1.12.1
+ * jQuery UI Effects Shake 1.13.0-rc.2
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -14,6 +14,8 @@
//>>demos: http://jqueryui.com/effect/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -26,7 +28,8 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.effects.define( "shake", function( options, done ) {
@@ -70,4 +73,4 @@ return $.effects.define( "shake", function( options, done ) {
$.effects.unshift( element, queuelen, anims + 1 );
} );
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/effect-size.js b/src/js/_enqueues/vendor/jquery/ui/effect-size.js
index 8449271aff..28a9d6c9d4 100644
--- a/src/js/_enqueues/vendor/jquery/ui/effect-size.js
+++ b/src/js/_enqueues/vendor/jquery/ui/effect-size.js
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Effects Size 1.12.1
+ * jQuery UI Effects Size 1.13.0-rc.2
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -14,6 +14,8 @@
//>>demos: http://jqueryui.com/effect/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -26,7 +28,8 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.effects.define( "size", function( options, done ) {
@@ -104,6 +107,8 @@ return $.effects.define( "size", function( options, done ) {
to.top = ( original.outerHeight - to.outerHeight ) * baseline.y + pos.top;
to.left = ( original.outerWidth - to.outerWidth ) * baseline.x + pos.left;
}
+ delete from.outerHeight;
+ delete from.outerWidth;
element.css( from );
// Animate the children if desired
@@ -187,4 +192,4 @@ return $.effects.define( "size", function( options, done ) {
} );
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/effect-slide.js b/src/js/_enqueues/vendor/jquery/ui/effect-slide.js
index 055d1d4879..34c2aae290 100644
--- a/src/js/_enqueues/vendor/jquery/ui/effect-slide.js
+++ b/src/js/_enqueues/vendor/jquery/ui/effect-slide.js
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Effects Slide 1.12.1
+ * jQuery UI Effects Slide 1.13.0-rc.2
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -14,6 +14,8 @@
//>>demos: http://jqueryui.com/effect/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -26,7 +28,8 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.effects.define( "slide", "show", function( options, done ) {
var startClip, startRef,
@@ -72,4 +75,4 @@ return $.effects.define( "slide", "show", function( options, done ) {
} );
} );
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/effect-transfer.js b/src/js/_enqueues/vendor/jquery/ui/effect-transfer.js
index 6c2e3ac1ad..ecdd495fcc 100644
--- a/src/js/_enqueues/vendor/jquery/ui/effect-transfer.js
+++ b/src/js/_enqueues/vendor/jquery/ui/effect-transfer.js
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Effects Transfer 1.12.1
+ * jQuery UI Effects Transfer 1.13.0-rc.2
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -14,6 +14,8 @@
//>>demos: http://jqueryui.com/effect/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -26,7 +28,8 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
var effect;
if ( $.uiBackCompat !== false ) {
@@ -36,4 +39,4 @@ if ( $.uiBackCompat !== false ) {
}
return effect;
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/effect.js b/src/js/_enqueues/vendor/jquery/ui/effect.js
index d1031bb3a7..a9952d980a 100644
--- a/src/js/_enqueues/vendor/jquery/ui/effect.js
+++ b/src/js/_enqueues/vendor/jquery/ui/effect.js
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Effects 1.12.1
+ * jQuery UI Effects 1.13.0-rc.2
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -9,13 +9,15 @@
//>>label: Effects Core
//>>group: Effects
-// jscs:disable maximumLineLength
+/* eslint-disable max-len */
//>>description: Extends the internal jQuery effects. Includes morphing and easing. Required by all other effects.
-// jscs:enable maximumLineLength
+/* eslint-enable max-len */
//>>docs: http://api.jqueryui.com/category/effects-core/
//>>demos: http://jqueryui.com/effect/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -25,43 +27,42 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
// Include version.js
$.ui = $.ui || {};
-$.ui.version = "1.12.1";
+$.ui.version = "1.13.0-rc.2";
-var dataSpace = "ui-effects-",
- dataSpaceStyle = "ui-effects-style",
- dataSpaceAnimated = "ui-effects-animated",
+// Source: jquery-var-for-color.js
+// Create a local jQuery because jQuery Color relies on it and the
+// global may not exist with AMD and a custom build (#10199).
+// This module is a noop if used as a regular AMD module.
+// eslint-disable-next-line no-unused-vars
+var jQuery = $;
- // Create a local jQuery because jQuery Color relies on it and the
- // global may not exist with AMD and a custom build (#10199)
- jQuery = $;
-
-$.effects = {
- effect: {}
-};
/*!
- * jQuery Color Animations v2.1.2
+ * jQuery Color Animations v2.2.0
* https://github.com/jquery/jquery-color
*
- * Copyright 2014 jQuery Foundation and other contributors
+ * Copyright OpenJS Foundation and other contributors
* Released under the MIT license.
* http://jquery.org/license
*
- * Date: Wed Jan 16 08:47:09 2013 -0600
+ * Date: Sun May 10 09:02:36 2020 +0200
*/
-( function( jQuery, undefined ) {
var stepHooks = "backgroundColor borderBottomColor borderLeftColor borderRightColor " +
"borderTopColor color columnRuleColor outlineColor textDecorationColor textEmphasisColor",
- // Plusequals test for += 100 -= 100
+ class2type = {},
+ toString = class2type.toString,
+
+ // plusequals test for += 100 -= 100
rplusequals = /^([\-+])=\s*(\d+\.?\d*)/,
- // A set of RE's that can match strings and generate color tuples.
+ // a set of RE's that can match strings and generate color tuples.
stringParsers = [ {
re: /rgba?\(\s*(\d{1,3})\s*,\s*(\d{1,3})\s*,\s*(\d{1,3})\s*(?:,\s*(\d?(?:\.\d+)?)\s*)?\)/,
parse: function( execResult ) {
@@ -84,24 +85,31 @@ $.effects = {
}
}, {
- // This regex ignores A-F because it's compared against an already lowercased string
- re: /#([a-f0-9]{2})([a-f0-9]{2})([a-f0-9]{2})/,
+ // this regex ignores A-F because it's compared against an already lowercased string
+ re: /#([a-f0-9]{2})([a-f0-9]{2})([a-f0-9]{2})([a-f0-9]{2})?/,
parse: function( execResult ) {
return [
parseInt( execResult[ 1 ], 16 ),
parseInt( execResult[ 2 ], 16 ),
- parseInt( execResult[ 3 ], 16 )
+ parseInt( execResult[ 3 ], 16 ),
+ execResult[ 4 ] ?
+ ( parseInt( execResult[ 4 ], 16 ) / 255 ).toFixed( 2 ) :
+ 1
];
}
}, {
- // This regex ignores A-F because it's compared against an already lowercased string
- re: /#([a-f0-9])([a-f0-9])([a-f0-9])/,
+ // this regex ignores A-F because it's compared against an already lowercased string
+ re: /#([a-f0-9])([a-f0-9])([a-f0-9])([a-f0-9])?/,
parse: function( execResult ) {
return [
parseInt( execResult[ 1 ] + execResult[ 1 ], 16 ),
parseInt( execResult[ 2 ] + execResult[ 2 ], 16 ),
- parseInt( execResult[ 3 ] + execResult[ 3 ], 16 )
+ parseInt( execResult[ 3 ] + execResult[ 3 ], 16 ),
+ execResult[ 4 ] ?
+ ( parseInt( execResult[ 4 ] + execResult[ 4 ], 16 ) / 255 )
+ .toFixed( 2 ) :
+ 1
];
}
}, {
@@ -117,7 +125,7 @@ $.effects = {
}
} ],
- // JQuery.Color( )
+ // jQuery.Color( )
color = jQuery.Color = function( color, green, blue, alpha ) {
return new jQuery.Color.fn.parse( color, green, blue, alpha );
},
@@ -171,20 +179,20 @@ $.effects = {
},
support = color.support = {},
- // Element for support tests
+ // element for support tests
supportElem = jQuery( "
" )[ 0 ],
- // Colors = jQuery.Color.names
+ // colors = jQuery.Color.names
colors,
- // Local aliases of functions called often
+ // local aliases of functions called often
each = jQuery.each;
-// Determine rgba support immediately
+// determine rgba support immediately
supportElem.style.cssText = "background-color:rgba(1,1,1,.5)";
support.rgba = supportElem.style.backgroundColor.indexOf( "rgba" ) > -1;
-// Define cache name and alpha properties
+// define cache name and alpha properties
// for rgba and hsla spaces
each( spaces, function( spaceName, space ) {
space.cache = "_" + spaceName;
@@ -195,6 +203,22 @@ each( spaces, function( spaceName, space ) {
};
} );
+// Populate the class2type map
+jQuery.each( "Boolean Number String Function Array Date RegExp Object Error Symbol".split( " " ),
+ function( _i, name ) {
+ class2type[ "[object " + name + "]" ] = name.toLowerCase();
+ } );
+
+function getType( obj ) {
+ if ( obj == null ) {
+ return obj + "";
+ }
+
+ return typeof obj === "object" ?
+ class2type[ toString.call( obj ) ] || "object" :
+ typeof obj;
+}
+
function clamp( value, prop, allowEmpty ) {
var type = propTypes[ prop.type ] || {};
@@ -213,13 +237,13 @@ function clamp( value, prop, allowEmpty ) {
if ( type.mod ) {
- // We add mod before modding to make sure that negatives values
+ // we add mod before modding to make sure that negatives values
// get converted properly: -10 -> 350
return ( value + type.mod ) % type.mod;
}
- // For now all property types without mod have min and max
- return 0 > value ? 0 : type.max < value ? type.max : value;
+ // for now all property types without mod have min and max
+ return Math.min( type.max, Math.max( 0, value ) );
}
function stringParse( string ) {
@@ -228,7 +252,7 @@ function stringParse( string ) {
string = string.toLowerCase();
- each( stringParsers, function( i, parser ) {
+ each( stringParsers, function( _i, parser ) {
var parsed,
match = parser.re.exec( string ),
values = match && parser.parse( match ),
@@ -237,12 +261,12 @@ function stringParse( string ) {
if ( values ) {
parsed = inst[ spaceName ]( values );
- // If this was an rgba parse the assignment might happen twice
+ // if this was an rgba parse the assignment might happen twice
// oh well....
inst[ spaces[ spaceName ].cache ] = parsed[ spaces[ spaceName ].cache ];
rgba = inst._rgba = parsed._rgba;
- // Exit each( stringParsers ) here because we matched
+ // exit each( stringParsers ) here because we matched
return false;
}
} );
@@ -250,7 +274,7 @@ function stringParse( string ) {
// Found a stringParser that handled it
if ( rgba.length ) {
- // If this came from a parsed string, force "transparent" when alpha is 0
+ // if this came from a parsed string, force "transparent" when alpha is 0
// chrome, (and maybe others) return "transparent" as rgba(0,0,0,0)
if ( rgba.join() === "0,0,0,0" ) {
jQuery.extend( rgba, colors.transparent );
@@ -258,7 +282,7 @@ function stringParse( string ) {
return inst;
}
- // Named colors
+ // named colors
return colors[ string ];
}
@@ -274,10 +298,10 @@ color.fn = jQuery.extend( color.prototype, {
}
var inst = this,
- type = jQuery.type( red ),
+ type = getType( red ),
rgba = this._rgba = [];
- // More than 1 argument specified - assume ( red, green, blue, alpha )
+ // more than 1 argument specified - assume ( red, green, blue, alpha )
if ( green !== undefined ) {
red = [ red, green, blue, alpha ];
type = "array";
@@ -288,7 +312,7 @@ color.fn = jQuery.extend( color.prototype, {
}
if ( type === "array" ) {
- each( spaces.rgba.props, function( key, prop ) {
+ each( spaces.rgba.props, function( _key, prop ) {
rgba[ prop.idx ] = clamp( red[ prop.idx ], prop );
} );
return this;
@@ -296,20 +320,20 @@ color.fn = jQuery.extend( color.prototype, {
if ( type === "object" ) {
if ( red instanceof color ) {
- each( spaces, function( spaceName, space ) {
+ each( spaces, function( _spaceName, space ) {
if ( red[ space.cache ] ) {
inst[ space.cache ] = red[ space.cache ].slice();
}
} );
} else {
- each( spaces, function( spaceName, space ) {
+ each( spaces, function( _spaceName, space ) {
var cache = space.cache;
each( space.props, function( key, prop ) {
- // If the cache doesn't exist, and we know how to convert
+ // if the cache doesn't exist, and we know how to convert
if ( !inst[ cache ] && space.to ) {
- // If the value was null, we don't need to copy it
+ // if the value was null, we don't need to copy it
// if the key was alpha, we don't need to copy it either
if ( key === "alpha" || red[ key ] == null ) {
return;
@@ -317,17 +341,19 @@ color.fn = jQuery.extend( color.prototype, {
inst[ cache ] = space.to( inst._rgba );
}
- // This is the only case where we allow nulls for ALL properties.
+ // this is the only case where we allow nulls for ALL properties.
// call clamp with alwaysAllowEmpty
inst[ cache ][ prop.idx ] = clamp( red[ key ], prop, true );
} );
- // Everything defined but alpha?
- if ( inst[ cache ] &&
- jQuery.inArray( null, inst[ cache ].slice( 0, 3 ) ) < 0 ) {
+ // everything defined but alpha?
+ if ( inst[ cache ] && jQuery.inArray( null, inst[ cache ].slice( 0, 3 ) ) < 0 ) {
+
+ // use the default of 1
+ if ( inst[ cache ][ 3 ] == null ) {
+ inst[ cache ][ 3 ] = 1;
+ }
- // Use the default of 1
- inst[ cache ][ 3 ] = 1;
if ( space.from ) {
inst._rgba = space.from( inst[ cache ] );
}
@@ -377,18 +403,18 @@ color.fn = jQuery.extend( color.prototype, {
result = start.slice();
end = end[ space.cache ];
- each( space.props, function( key, prop ) {
+ each( space.props, function( _key, prop ) {
var index = prop.idx,
startValue = start[ index ],
endValue = end[ index ],
type = propTypes[ prop.type ] || {};
- // If null, don't override start value
+ // if null, don't override start value
if ( endValue === null ) {
return;
}
- // If null - use end
+ // if null - use end
if ( startValue === null ) {
result[ index ] = endValue;
} else {
@@ -406,7 +432,7 @@ color.fn = jQuery.extend( color.prototype, {
},
blend: function( opaque ) {
- // If we are already opaque - return ourself
+ // if we are already opaque - return ourself
if ( this._rgba[ 3 ] === 1 ) {
return this;
}
@@ -422,7 +448,10 @@ color.fn = jQuery.extend( color.prototype, {
toRgbaString: function() {
var prefix = "rgba(",
rgba = jQuery.map( this._rgba, function( v, i ) {
- return v == null ? ( i > 2 ? 1 : 0 ) : v;
+ if ( v != null ) {
+ return v;
+ }
+ return i > 2 ? 1 : 0;
} );
if ( rgba[ 3 ] === 1 ) {
@@ -439,7 +468,7 @@ color.fn = jQuery.extend( color.prototype, {
v = i > 2 ? 1 : 0;
}
- // Catch 1 and 2
+ // catch 1 and 2
if ( i && i < 3 ) {
v = Math.round( v * 100 ) + "%";
}
@@ -462,7 +491,7 @@ color.fn = jQuery.extend( color.prototype, {
return "#" + jQuery.map( rgba, function( v ) {
- // Default to 0 when nulls exist
+ // default to 0 when nulls exist
v = ( v || 0 ).toString( 16 );
return v.length === 1 ? "0" + v : v;
} ).join( "" );
@@ -473,7 +502,7 @@ color.fn = jQuery.extend( color.prototype, {
} );
color.fn.parse.prototype = color.fn;
-// Hsla conversions adapted from:
+// hsla conversions adapted from:
// https://code.google.com/p/maashaack/source/browse/packages/graphics/trunk/src/graphics/colors/HUE2RGB.as?r=5021
function hue2rgb( p, q, h ) {
@@ -515,7 +544,7 @@ spaces.hsla.to = function( rgba ) {
h = ( 60 * ( r - g ) / diff ) + 240;
}
- // Chroma (diff) == 0 means greyscale which, by definition, saturation = 0%
+ // chroma (diff) == 0 means greyscale which, by definition, saturation = 0%
// otherwise, saturation is based on the ratio of chroma (diff) to lightness (add)
if ( diff === 0 ) {
s = 0;
@@ -546,16 +575,17 @@ spaces.hsla.from = function( hsla ) {
];
};
+
each( spaces, function( spaceName, space ) {
var props = space.props,
cache = space.cache,
to = space.to,
from = space.from;
- // Makes rgba() and hsla()
+ // makes rgba() and hsla()
color.fn[ spaceName ] = function( value ) {
- // Generate a cache for this space if it doesn't exist
+ // generate a cache for this space if it doesn't exist
if ( to && !this[ cache ] ) {
this[ cache ] = to( this._rgba );
}
@@ -564,7 +594,7 @@ each( spaces, function( spaceName, space ) {
}
var ret,
- type = jQuery.type( value ),
+ type = getType( value ),
arr = ( type === "array" || type === "object" ) ? value : arguments,
local = this[ cache ].slice();
@@ -585,19 +615,24 @@ each( spaces, function( spaceName, space ) {
}
};
- // Makes red() green() blue() alpha() hue() saturation() lightness()
+ // makes red() green() blue() alpha() hue() saturation() lightness()
each( props, function( key, prop ) {
- // Alpha is included in more than one space
+ // alpha is included in more than one space
if ( color.fn[ key ] ) {
return;
}
color.fn[ key ] = function( value ) {
- var vtype = jQuery.type( value ),
- fn = ( key === "alpha" ? ( this._hsla ? "hsla" : "rgba" ) : spaceName ),
- local = this[ fn ](),
- cur = local[ prop.idx ],
- match;
+ var local, cur, match, fn,
+ vtype = getType( value );
+
+ if ( key === "alpha" ) {
+ fn = this._hsla ? "hsla" : "rgba";
+ } else {
+ fn = spaceName;
+ }
+ local = this[ fn ]();
+ cur = local[ prop.idx ];
if ( vtype === "undefined" ) {
return cur;
@@ -605,7 +640,7 @@ each( spaces, function( spaceName, space ) {
if ( vtype === "function" ) {
value = value.call( this, cur );
- vtype = jQuery.type( value );
+ vtype = getType( value );
}
if ( value == null && prop.empty ) {
return this;
@@ -622,18 +657,17 @@ each( spaces, function( spaceName, space ) {
} );
} );
-// Add cssHook and .fx.step function for each named hook.
+// add cssHook and .fx.step function for each named hook.
// accept a space separated string of properties
color.hook = function( hook ) {
var hooks = hook.split( " " );
- each( hooks, function( i, hook ) {
+ each( hooks, function( _i, hook ) {
jQuery.cssHooks[ hook ] = {
set: function( elem, value ) {
var parsed, curElem,
backgroundColor = "";
- if ( value !== "transparent" && ( jQuery.type( value ) !== "string" ||
- ( parsed = stringParse( value ) ) ) ) {
+ if ( value !== "transparent" && ( getType( value ) !== "string" || ( parsed = stringParse( value ) ) ) ) {
value = color( parsed || value );
if ( !support.rgba && value._rgba[ 3 ] !== 1 ) {
curElem = hook === "backgroundColor" ? elem.parentNode : elem;
@@ -659,8 +693,7 @@ color.hook = function( hook ) {
elem.style[ hook ] = value;
} catch ( e ) {
- // Wrapped to prevent IE from throwing errors on "invalid" values like
- // 'auto' or 'inherit'
+ // wrapped to prevent IE from throwing errors on "invalid" values like 'auto' or 'inherit'
}
}
};
@@ -682,7 +715,7 @@ jQuery.cssHooks.borderColor = {
expand: function( value ) {
var expanded = {};
- each( [ "Top", "Right", "Bottom", "Left" ], function( i, part ) {
+ each( [ "Top", "Right", "Bottom", "Left" ], function( _i, part ) {
expanded[ "border" + part + "Color" ] = value;
} );
return expanded;
@@ -718,7 +751,14 @@ colors = jQuery.Color.names = {
_default: "#ffffff"
};
-} )( jQuery );
+
+var dataSpace = "ui-effects-",
+ dataSpaceStyle = "ui-effects-style",
+ dataSpaceAnimated = "ui-effects-animated";
+
+$.effects = {
+ effect: {}
+};
/******************************************************************************/
/****************************** CLASS ANIMATIONS ******************************/
@@ -750,6 +790,12 @@ $.each(
}
);
+function camelCase( string ) {
+ return string.replace( /-([\da-z])/gi, function( all, letter ) {
+ return letter.toUpperCase();
+ } );
+}
+
function getElementStyles( elem ) {
var key, len,
style = elem.ownerDocument.defaultView ?
@@ -762,7 +808,7 @@ function getElementStyles( elem ) {
while ( len-- ) {
key = style[ len ];
if ( typeof style[ key ] === "string" ) {
- styles[ $.camelCase( key ) ] = style[ key ];
+ styles[ camelCase( key ) ] = style[ key ];
}
}
@@ -936,12 +982,12 @@ $.fn.extend( {
( function() {
-if ( $.expr && $.expr.filters && $.expr.filters.animated ) {
- $.expr.filters.animated = ( function( orig ) {
+if ( $.expr && $.expr.pseudos && $.expr.pseudos.animated ) {
+ $.expr.pseudos.animated = ( function( orig ) {
return function( elem ) {
return !!$( elem ).data( dataSpaceAnimated ) || orig( elem );
};
- } )( $.expr.filters.animated );
+ } )( $.expr.pseudos.animated );
}
if ( $.uiBackCompat !== false ) {
@@ -1010,6 +1056,7 @@ if ( $.uiBackCompat !== false ) {
// Firefox incorrectly exposes anonymous content
// https://bugzilla.mozilla.org/show_bug.cgi?id=561664
try {
+ // eslint-disable-next-line no-unused-expressions
active.id;
} catch ( e ) {
active = document.body;
@@ -1072,7 +1119,7 @@ if ( $.uiBackCompat !== false ) {
}
$.extend( $.effects, {
- version: "1.12.1",
+ version: "1.13.0-rc.2",
define: function( name, mode, effect ) {
if ( !effect ) {
@@ -1288,7 +1335,7 @@ function _normalizeArguments( effect, options, speed, callback ) {
}
// Catch (effect, callback)
- if ( $.isFunction( options ) ) {
+ if ( typeof options === "function" ) {
callback = options;
speed = null;
options = {};
@@ -1302,7 +1349,7 @@ function _normalizeArguments( effect, options, speed, callback ) {
}
// Catch (effect, options, callback)
- if ( $.isFunction( speed ) ) {
+ if ( typeof speed === "function" ) {
callback = speed;
speed = null;
}
@@ -1336,7 +1383,7 @@ function standardAnimationOption( option ) {
}
// Complete callback
- if ( $.isFunction( option ) ) {
+ if ( typeof option === "function" ) {
return true;
}
@@ -1363,7 +1410,7 @@ $.fn.extend( {
var el = $( this ),
normalizedMode = $.effects.mode( el, mode ) || defaultMode;
- // Sentinel for duck-punching the :animated psuedo-selector
+ // Sentinel for duck-punching the :animated pseudo-selector
el.data( dataSpaceAnimated, true );
// Save effect mode for later use,
@@ -1371,7 +1418,7 @@ $.fn.extend( {
// as the .show() below destroys the initial state
modes.push( normalizedMode );
- // See $.uiBackCompat inside of run() for removal of defaultMode in 1.13
+ // See $.uiBackCompat inside of run() for removal of defaultMode in 1.14
if ( defaultMode && ( normalizedMode === "show" ||
( normalizedMode === defaultMode && normalizedMode === "hide" ) ) ) {
el.show();
@@ -1381,7 +1428,7 @@ $.fn.extend( {
$.effects.saveStyle( el );
}
- if ( $.isFunction( next ) ) {
+ if ( typeof next === "function" ) {
next();
}
};
@@ -1416,11 +1463,11 @@ $.fn.extend( {
}
function done() {
- if ( $.isFunction( complete ) ) {
+ if ( typeof complete === "function" ) {
complete.call( elem[ 0 ] );
}
- if ( $.isFunction( next ) ) {
+ if ( typeof next === "function" ) {
next();
}
}
@@ -1529,22 +1576,24 @@ $.fn.extend( {
width: target.innerWidth()
},
startPosition = element.offset(),
- transfer = $( "
" )
- .appendTo( "body" )
- .addClass( options.className )
- .css( {
- top: startPosition.top - fixTop,
- left: startPosition.left - fixLeft,
- height: element.innerHeight(),
- width: element.innerWidth(),
- position: targetFixed ? "fixed" : "absolute"
- } )
- .animate( animation, options.duration, options.easing, function() {
- transfer.remove();
- if ( $.isFunction( done ) ) {
- done();
- }
- } );
+ transfer = $( "
" );
+
+ transfer
+ .appendTo( "body" )
+ .addClass( options.className )
+ .css( {
+ top: startPosition.top - fixTop,
+ left: startPosition.left - fixLeft,
+ height: element.innerHeight(),
+ width: element.innerWidth(),
+ position: targetFixed ? "fixed" : "absolute"
+ } )
+ .animate( animation, options.duration, options.easing, function() {
+ transfer.remove();
+ if ( typeof done === "function" ) {
+ done();
+ }
+ } );
}
} );
@@ -1636,4 +1685,4 @@ $.each( baseEasings, function( name, easeIn ) {
return $.effects;
-} ) );
+} );
diff --git a/src/js/_enqueues/vendor/jquery/ui/draggable.js b/src/js/_enqueues/vendor/jquery/ui/draggable.js
index 7a1746fd19..3ba056a75d 100644
--- a/src/js/_enqueues/vendor/jquery/ui/draggable.js
+++ b/src/js/_enqueues/vendor/jquery/ui/draggable.js
@@ -1,5 +1,5 @@
/*!
* jQuery UI Draggable 1.12.1
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -15,6 +15,8 @@
//>>css.structure: ../../themes/base/draggable.css
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -28,10 +30,11 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
$.widget( "ui.draggable", $.ui.mouse, {
- version: "1.12.1",
+ version: "1.13.0-rc.2",
widgetEventPrefix: "drag",
options: {
addClasses: true,
@@ -195,7 +198,9 @@ $.widget( "ui.draggable", $.ui.mouse, {
this.originalPageY = event.pageY;
//Adjust the mouse offset relative to the helper if "cursorAt" is supplied
- ( o.cursorAt && this._adjustOffsetFromHelper( o.cursorAt ) );
+ if ( o.cursorAt ) {
+ this._adjustOffsetFromHelper( o.cursorAt );
+ }
//Set a containment if given in the options
this._setContainment();
@@ -290,7 +295,7 @@ $.widget( "ui.draggable", $.ui.mouse, {
if ( ( this.options.revert === "invalid" && !dropped ) ||
( this.options.revert === "valid" && dropped ) ||
- this.options.revert === true || ( $.isFunction( this.options.revert ) &&
+ this.options.revert === true || ( typeof this.options.revert === "function" &&
this.options.revert.call( this.element, dropped ) )
) {
$( this.helper ).animate(
@@ -362,7 +367,7 @@ $.widget( "ui.draggable", $.ui.mouse, {
_createHelper: function( event ) {
var o = this.options,
- helperIsFunction = $.isFunction( o.helper ),
+ helperIsFunction = typeof o.helper === "function",
helper = helperIsFunction ?
$( o.helper.apply( this.element[ 0 ], [ event ] ) ) :
( o.helper === "clone" ?
@@ -401,7 +406,7 @@ $.widget( "ui.draggable", $.ui.mouse, {
if ( typeof obj === "string" ) {
obj = obj.split( " " );
}
- if ( $.isArray( obj ) ) {
+ if ( Array.isArray( obj ) ) {
obj = { left: +obj[ 0 ], top: +obj[ 1 ] || 0 };
}
if ( "left" in obj ) {
@@ -1110,12 +1115,13 @@ $.ui.plugin.add( "draggable", "snap", {
!$.contains( inst.snapElements[ i ].item.ownerDocument,
inst.snapElements[ i ].item ) ) {
if ( inst.snapElements[ i ].snapping ) {
- ( inst.options.snap.release &&
+ if ( inst.options.snap.release ) {
inst.options.snap.release.call(
inst.element,
event,
$.extend( inst._uiHash(), { snapItem: inst.snapElements[ i ].item } )
- ) );
+ );
+ }
}
inst.snapElements[ i ].snapping = false;
continue;
@@ -1186,13 +1192,14 @@ $.ui.plugin.add( "draggable", "snap", {
}
if ( !inst.snapElements[ i ].snapping && ( ts || bs || ls || rs || first ) ) {
- ( inst.options.snap.snap &&
+ if ( inst.options.snap.snap ) {
inst.options.snap.snap.call(
inst.element,
event,
$.extend( inst._uiHash(), {
snapItem: inst.snapElements[ i ].item
- } ) ) );
+ } ) );
+ }
}
inst.snapElements[ i ].snapping = ( ts || bs || ls || rs || first );
@@ -1210,7 +1217,9 @@ $.ui.plugin.add( "draggable", "stack", {
( parseInt( $( b ).css( "zIndex" ), 10 ) || 0 );
} );
- if ( !group.length ) { return; }
+ if ( !group.length ) {
+ return;
+ }
min = parseInt( $( group[ 0 ] ).css( "zIndex" ), 10 ) || 0;
$( group ).each( function( i ) {
@@ -1241,4 +1250,4 @@ $.ui.plugin.add( "draggable", "zIndex", {
return $.ui.draggable;
-} ) );
+} );
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Draggable 1.12.1
+ * jQuery UI Draggable 1.13.0-rc.2
* http://jqueryui.com
*
diff --git a/src/js/_enqueues/vendor/jquery/ui/droppable.js b/src/js/_enqueues/vendor/jquery/ui/droppable.js
index b71cc30bce..1770ab2f1f 100644
--- a/src/js/_enqueues/vendor/jquery/ui/droppable.js
+++ b/src/js/_enqueues/vendor/jquery/ui/droppable.js
@@ -1,5 +1,5 @@
/*!
* jQuery UI Droppable 1.12.1
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -14,6 +14,8 @@
//>>demos: http://jqueryui.com/droppable/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -28,10 +30,11 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
$.widget( "ui.droppable", {
- version: "1.12.1",
+ version: "1.13.0-rc.2",
widgetEventPrefix: "drop",
options: {
accept: "*",
@@ -56,7 +59,7 @@ $.widget( "ui.droppable", {
this.isover = false;
this.isout = true;
- this.accept = $.isFunction( accept ) ? accept : function( d ) {
+ this.accept = typeof accept === "function" ? accept : function( d ) {
return d.is( accept );
};
@@ -79,7 +82,9 @@ $.widget( "ui.droppable", {
this._addToManager( o.scope );
- o.addClasses && this._addClass( "ui-droppable" );
+ if ( o.addClasses ) {
+ this._addClass( "ui-droppable" );
+ }
},
@@ -108,7 +113,7 @@ $.widget( "ui.droppable", {
_setOption: function( key, value ) {
if ( key === "accept" ) {
- this.accept = $.isFunction( value ) ? value : function( d ) {
+ this.accept = typeof value === "function" ? value : function( d ) {
return d.is( value );
};
} else if ( key === "scope" ) {
@@ -198,14 +203,15 @@ $.widget( "ui.droppable", {
inst.accept.call(
inst.element[ 0 ], ( draggable.currentItem || draggable.element )
) &&
- intersect(
+ $.ui.intersect(
draggable,
$.extend( inst, { offset: inst.element.offset() } ),
inst.options.tolerance, event
)
) {
childrenIntersection = true;
- return false; }
+ return false;
+ }
} );
if ( childrenIntersection ) {
return false;
@@ -234,7 +240,7 @@ $.widget( "ui.droppable", {
},
// Extension points just to make backcompat sane and avoid duplicating logic
- // TODO: Remove in 1.13 along with call to it below
+ // TODO: Remove in 1.14 along with call to it below
_addHoverClass: function() {
this._addClass( "ui-droppable-hover" );
},
@@ -252,7 +258,7 @@ $.widget( "ui.droppable", {
}
} );
-var intersect = $.ui.intersect = ( function() {
+$.ui.intersect = ( function() {
function isOverAxis( x, reference, size ) {
return ( x >= reference ) && ( x < ( reference + size ) );
}
@@ -360,7 +366,7 @@ $.ui.ddmanager = {
return;
}
if ( !this.options.disabled && this.visible &&
- intersect( draggable, this, this.options.tolerance, event ) ) {
+ $.ui.intersect( draggable, this, this.options.tolerance, event ) ) {
dropped = this._drop.call( this, event ) || dropped;
}
@@ -401,7 +407,7 @@ $.ui.ddmanager = {
}
var parentInstance, scope, parent,
- intersects = intersect( draggable, this, this.options.tolerance, event ),
+ intersects = $.ui.intersect( draggable, this, this.options.tolerance, event ),
c = !intersects && this.isover ?
"isout" :
( intersects && !this.isover ? "isover" : null );
@@ -493,4 +499,4 @@ if ( $.uiBackCompat !== false ) {
return $.ui.droppable;
-} ) );
+} );
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Droppable 1.12.1
+ * jQuery UI Droppable 1.13.0-rc.2
* http://jqueryui.com
*
diff --git a/src/js/_enqueues/vendor/jquery/ui/menu.js b/src/js/_enqueues/vendor/jquery/ui/menu.js
index f5c4f73115..f06be2c4ae 100644
--- a/src/js/_enqueues/vendor/jquery/ui/menu.js
+++ b/src/js/_enqueues/vendor/jquery/ui/menu.js
@@ -1,5 +1,5 @@
/*!
* jQuery UI Menu 1.12.1
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -17,6 +17,8 @@
//>>css.theme: ../../themes/base/theme.css
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -29,10 +31,11 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.widget( "ui.menu", {
- version: "1.12.1",
+ version: "1.13.0-rc.2",
defaultElement: "
",
delay: 300,
options: {
@@ -59,6 +62,7 @@ return $.widget( "ui.menu", {
// Flag used to prevent firing of the click handler
// as the event bubbles up through nested menus
this.mouseHandled = false;
+ this.lastMousePosition = { x: null, y: null };
this.element
.uniqueId()
.attr( {
@@ -73,6 +77,8 @@ return $.widget( "ui.menu", {
// them (focus should always stay on UL during navigation).
"mousedown .ui-menu-item": function( event ) {
event.preventDefault();
+
+ this._activateItem( event );
},
"click .ui-menu-item": function( event ) {
var target = $( event.target );
@@ -102,36 +108,15 @@ return $.widget( "ui.menu", {
}
}
},
- "mouseenter .ui-menu-item": function( event ) {
-
- // Ignore mouse events while typeahead is active, see #10458.
- // Prevents focusing the wrong item when typeahead causes a scroll while the mouse
- // is over an item in the menu
- if ( this.previousFilter ) {
- return;
- }
-
- var actualTarget = $( event.target ).closest( ".ui-menu-item" ),
- target = $( event.currentTarget );
-
- // Ignore bubbled events on parent items, see #11641
- if ( actualTarget[ 0 ] !== target[ 0 ] ) {
- return;
- }
-
- // Remove ui-state-active class from siblings of the newly focused menu item
- // to avoid a jump caused by adjacent elements both having a class with a border
- this._removeClass( target.siblings().children( ".ui-state-active" ),
- null, "ui-state-active" );
- this.focus( event, target );
- },
+ "mouseenter .ui-menu-item": "_activateItem",
+ "mousemove .ui-menu-item": "_activateItem",
mouseleave: "collapseAll",
"mouseleave .ui-menu": "collapseAll",
focus: function( event, keepActiveItem ) {
// If there's already an active item, keep it active
// If not, activate the first item
- var item = this.active || this.element.find( this.options.items ).eq( 0 );
+ var item = this.active || this._menuItems().first();
if ( !keepActiveItem ) {
this.focus( event, item );
@@ -157,7 +142,7 @@ return $.widget( "ui.menu", {
this._on( this.document, {
click: function( event ) {
if ( this._closeOnDocumentClick( event ) ) {
- this.collapseAll( event );
+ this.collapseAll( event, true );
}
// Reset the mouseHandled flag
@@ -166,6 +151,46 @@ return $.widget( "ui.menu", {
} );
},
+ _activateItem: function( event ) {
+
+ // Ignore mouse events while typeahead is active, see #10458.
+ // Prevents focusing the wrong item when typeahead causes a scroll while the mouse
+ // is over an item in the menu
+ if ( this.previousFilter ) {
+ return;
+ }
+
+ // If the mouse didn't actually move, but the page was scrolled, ignore the event (#9356)
+ if ( event.clientX === this.lastMousePosition.x &&
+ event.clientY === this.lastMousePosition.y ) {
+ return;
+ }
+
+ this.lastMousePosition = {
+ x: event.clientX,
+ y: event.clientY
+ };
+
+ var actualTarget = $( event.target ).closest( ".ui-menu-item" ),
+ target = $( event.currentTarget );
+
+ // Ignore bubbled events on parent items, see #11641
+ if ( actualTarget[ 0 ] !== target[ 0 ] ) {
+ return;
+ }
+
+ // If the item is already active, there's nothing to do
+ if ( target.is( ".ui-state-active" ) ) {
+ return;
+ }
+
+ // Remove ui-state-active class from siblings of the newly focused menu item
+ // to avoid a jump caused by adjacent elements both having a class with a border
+ this._removeClass( target.siblings().children( ".ui-state-active" ),
+ null, "ui-state-active" );
+ this.focus( event, target );
+ },
+
_destroy: function() {
var items = this.element.find( ".ui-menu-item" )
.removeAttr( "role aria-disabled" ),
@@ -497,7 +522,7 @@ return $.widget( "ui.menu", {
this._removeClass( currentMenu.find( ".ui-state-active" ), null, "ui-state-active" );
this.activeMenu = currentMenu;
- }, this.delay );
+ }, all ? 0 : this.delay );
},
// With no arguments, closes the currently active menu - if nothing is active
@@ -533,11 +558,7 @@ return $.widget( "ui.menu", {
},
expand: function( event ) {
- var newItem = this.active &&
- this.active
- .children( ".ui-menu " )
- .find( this.options.items )
- .first();
+ var newItem = this.active && this._menuItems( this.active.children( ".ui-menu" ) ).first();
if ( newItem && newItem.length ) {
this._open( newItem.parent() );
@@ -565,21 +586,27 @@ return $.widget( "ui.menu", {
return this.active && !this.active.nextAll( ".ui-menu-item" ).length;
},
+ _menuItems: function( menu ) {
+ return ( menu || this.element )
+ .find( this.options.items )
+ .filter( ".ui-menu-item" );
+ },
+
_move: function( direction, filter, event ) {
var next;
if ( this.active ) {
if ( direction === "first" || direction === "last" ) {
next = this.active
[ direction === "first" ? "prevAll" : "nextAll" ]( ".ui-menu-item" )
- .eq( -1 );
+ .last();
} else {
next = this.active
[ direction + "All" ]( ".ui-menu-item" )
- .eq( 0 );
+ .first();
}
}
if ( !next || !next.length || !this.active ) {
- next = this.activeMenu.find( this.options.items )[ filter ]();
+ next = this._menuItems( this.activeMenu )[ filter ]();
}
this.focus( event, next );
@@ -597,7 +624,13 @@ return $.widget( "ui.menu", {
}
if ( this._hasScroll() ) {
base = this.active.offset().top;
- height = this.element.height();
+ height = this.element.innerHeight();
+
+ // jQuery 3.2 doesn't include scrollbars in innerHeight, add it back.
+ if ( $.fn.jquery.indexOf( "3.2." ) === 0 ) {
+ height += this.element[ 0 ].offsetHeight - this.element.outerHeight();
+ }
+
this.active.nextAll( ".ui-menu-item" ).each( function() {
item = $( this );
return item.offset().top - base - height < 0;
@@ -605,7 +638,7 @@ return $.widget( "ui.menu", {
this.focus( event, item );
} else {
- this.focus( event, this.activeMenu.find( this.options.items )
+ this.focus( event, this._menuItems( this.activeMenu )
[ !this.active ? "first" : "last" ]() );
}
},
@@ -621,7 +654,13 @@ return $.widget( "ui.menu", {
}
if ( this._hasScroll() ) {
base = this.active.offset().top;
- height = this.element.height();
+ height = this.element.innerHeight();
+
+ // jQuery 3.2 doesn't include scrollbars in innerHeight, add it back.
+ if ( $.fn.jquery.indexOf( "3.2." ) === 0 ) {
+ height += this.element[ 0 ].offsetHeight - this.element.outerHeight();
+ }
+
this.active.prevAll( ".ui-menu-item" ).each( function() {
item = $( this );
return item.offset().top - base + height > 0;
@@ -629,7 +668,7 @@ return $.widget( "ui.menu", {
this.focus( event, item );
} else {
- this.focus( event, this.activeMenu.find( this.options.items ).first() );
+ this.focus( event, this._menuItems( this.activeMenu ).first() );
}
},
@@ -660,9 +699,10 @@ return $.widget( "ui.menu", {
.filter( ".ui-menu-item" )
.filter( function() {
return regex.test(
- $.trim( $( this ).children( ".ui-menu-item-wrapper" ).text() ) );
+ String.prototype.trim.call(
+ $( this ).children( ".ui-menu-item-wrapper" ).text() ) );
} );
}
} );
-} ) );
+} );
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Menu 1.12.1
+ * jQuery UI Menu 1.13.0-rc.2
* http://jqueryui.com
*
diff --git a/src/js/_enqueues/vendor/jquery/ui/mouse.js b/src/js/_enqueues/vendor/jquery/ui/mouse.js
index 54f5e48bc4..425d962bed 100644
--- a/src/js/_enqueues/vendor/jquery/ui/mouse.js
+++ b/src/js/_enqueues/vendor/jquery/ui/mouse.js
@@ -1,5 +1,5 @@
/*!
* jQuery UI Mouse 1.12.1
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -13,6 +13,8 @@
//>>docs: http://api.jqueryui.com/mouse/
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -25,7 +27,8 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
var mouseHandled = false;
$( document ).on( "mouseup", function() {
@@ -33,7 +36,7 @@ $( document ).on( "mouseup", function() {
} );
return $.widget( "ui.mouse", {
- version: "1.12.1",
+ version: "1.13.0-rc.2",
options: {
cancel: "input, textarea, button, select, option",
distance: 1,
@@ -78,7 +81,9 @@ return $.widget( "ui.mouse", {
this._mouseMoved = false;
// We may have missed mouseup (out of window)
- ( this._mouseStarted && this._mouseUp( event ) );
+ if ( this._mouseStarted ) {
+ this._mouseUp( event );
+ }
this._mouseDownEvent = event;
@@ -171,7 +176,11 @@ return $.widget( "ui.mouse", {
if ( this._mouseDistanceMet( event ) && this._mouseDelayMet( event ) ) {
this._mouseStarted =
( this._mouseStart( this._mouseDownEvent, event ) !== false );
- ( this._mouseStarted ? this._mouseDrag( event ) : this._mouseUp( event ) );
+ if ( this._mouseStarted ) {
+ this._mouseDrag( event );
+ } else {
+ this._mouseUp( event );
+ }
}
return !this._mouseStarted;
@@ -218,7 +227,9 @@ return $.widget( "ui.mouse", {
_mouseStart: function( /* event */ ) {},
_mouseDrag: function( /* event */ ) {},
_mouseStop: function( /* event */ ) {},
- _mouseCapture: function( /* event */ ) { return true; }
+ _mouseCapture: function( /* event */ ) {
+ return true;
+ }
} );
-} ) );
+} );
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Mouse 1.12.1
+ * jQuery UI Mouse 1.13.0-rc.2
* http://jqueryui.com
*
diff --git a/src/js/_enqueues/vendor/jquery/ui/progressbar.js b/src/js/_enqueues/vendor/jquery/ui/progressbar.js
index ff7dd90c85..6c30e97df1 100644
--- a/src/js/_enqueues/vendor/jquery/ui/progressbar.js
+++ b/src/js/_enqueues/vendor/jquery/ui/progressbar.js
@@ -1,5 +1,5 @@
/*!
* jQuery UI Progressbar 1.12.1
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -9,9 +9,9 @@
//>>label: Progressbar
//>>group: Widgets
-// jscs:disable maximumLineLength
+/* eslint-disable max-len */
//>>description: Displays a status indicator for loading state, standard percentage, and other progress indicators.
-// jscs:enable maximumLineLength
+/* eslint-enable max-len */
//>>docs: http://api.jqueryui.com/progressbar/
//>>demos: http://jqueryui.com/progressbar/
//>>css.structure: ../../themes/base/core.css
@@ -19,6 +19,8 @@
//>>css.theme: ../../themes/base/theme.css
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -31,10 +33,11 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.widget( "ui.progressbar", {
- version: "1.12.1",
+ version: "1.13.0-rc.2",
options: {
classes: {
"ui-progressbar": "ui-corner-all",
@@ -174,4 +177,4 @@ return $.widget( "ui.progressbar", {
}
} );
-} ) );
+} );
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Progressbar 1.12.1
+ * jQuery UI Progressbar 1.13.0-rc.2
* http://jqueryui.com
*
diff --git a/src/js/_enqueues/vendor/jquery/ui/resizable.js b/src/js/_enqueues/vendor/jquery/ui/resizable.js
index 62a0fc821b..acbc73aaff 100644
--- a/src/js/_enqueues/vendor/jquery/ui/resizable.js
+++ b/src/js/_enqueues/vendor/jquery/ui/resizable.js
@@ -1,5 +1,5 @@
/*!
* jQuery UI Resizable 1.12.1
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -17,6 +17,8 @@
//>>css.theme: ../../themes/base/theme.css
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -30,10 +32,11 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
$.widget( "ui.resizable", $.ui.mouse, {
- version: "1.12.1",
+ version: "1.13.0-rc.2",
widgetEventPrefix: "resize",
options: {
alsoResize: false,
@@ -88,9 +91,15 @@ $.widget( "ui.resizable", $.ui.mouse, {
// TODO: determine which cases actually cause this to happen
// if the element doesn't have the scroll set, see if it's possible to
// set the scroll
- el[ scroll ] = 1;
- has = ( el[ scroll ] > 0 );
- el[ scroll ] = 0;
+ try {
+ el[ scroll ] = 1;
+ has = ( el[ scroll ] > 0 );
+ el[ scroll ] = 0;
+ } catch ( e ) {
+
+ // `el` might be a string, then setting `scroll` will throw
+ // an error in strict mode; ignore it.
+ }
return has;
},
@@ -113,7 +122,8 @@ $.widget( "ui.resizable", $.ui.mouse, {
if ( this.element[ 0 ].nodeName.match( /^(canvas|textarea|input|select|button|img)$/i ) ) {
this.element.wrap(
- $( "" ).css( {
+ $( "" ).css( {
+ overflow: "hidden",
position: this.element.css( "position" ),
width: this.element.outerWidth(),
height: this.element.outerHeight(),
@@ -184,15 +194,14 @@ $.widget( "ui.resizable", $.ui.mouse, {
_destroy: function() {
this._mouseDestroy();
+ this._addedHandles.remove();
var wrapper,
_destroy = function( exp ) {
$( exp )
.removeData( "resizable" )
.removeData( "ui-resizable" )
- .off( ".resizable" )
- .find( ".ui-resizable-handle" )
- .remove();
+ .off( ".resizable" );
};
// TODO: Unwrap at same DOM position
@@ -223,6 +232,9 @@ $.widget( "ui.resizable", $.ui.mouse, {
this._removeHandles();
this._setupHandles();
break;
+ case "aspectRatio":
+ this._aspectRatio = !!value;
+ break;
default:
break;
}
@@ -244,6 +256,7 @@ $.widget( "ui.resizable", $.ui.mouse, {
} );
this._handles = $();
+ this._addedHandles = $();
if ( this.handles.constructor === String ) {
if ( this.handles === "all" ) {
@@ -255,7 +268,7 @@ $.widget( "ui.resizable", $.ui.mouse, {
for ( i = 0; i < n.length; i++ ) {
- handle = $.trim( n[ i ] );
+ handle = String.prototype.trim.call( n[ i ] );
hname = "ui-resizable-" + handle;
axis = $( "" );
this._addClass( axis, "ui-resizable-handle " + hname );
@@ -263,7 +276,10 @@ $.widget( "ui.resizable", $.ui.mouse, {
axis.css( { zIndex: o.zIndex } );
this.handles[ handle ] = ".ui-resizable-" + handle;
- this.element.append( axis );
+ if ( !this.element.children( this.handles[ handle ] ).length ) {
+ this.element.append( axis );
+ this._addedHandles = this._addedHandles.add( axis );
+ }
}
}
@@ -329,7 +345,7 @@ $.widget( "ui.resizable", $.ui.mouse, {
},
_removeHandles: function() {
- this._handles.remove();
+ this._addedHandles.remove();
},
_mouseCapture: function( event ) {
@@ -709,7 +725,7 @@ $.widget( "ui.resizable", $.ui.mouse, {
if ( this._helper ) {
- this.helper = this.helper || $( "
" );
+ this.helper = this.helper || $( "
" ).css( { overflow: "hidden" } );
this._addClass( this.helper, this._helper );
this.helper.css( {
@@ -766,7 +782,9 @@ $.widget( "ui.resizable", $.ui.mouse, {
_propagate: function( n, event ) {
$.ui.plugin.call( this, n, [ event, this.ui() ] );
- ( n !== "resize" && this._trigger( n, event, this.ui() ) );
+ if ( n !== "resize" ) {
+ this._trigger( n, event, this.ui() );
+ }
},
plugins: {},
@@ -887,8 +905,8 @@ $.ui.plugin.add( "resizable", "containment", {
co = that.containerOffset;
ch = that.containerSize.height;
cw = that.containerSize.width;
- width = ( that._hasScroll ( ce, "left" ) ? ce.scrollWidth : cw );
- height = ( that._hasScroll ( ce ) ? ce.scrollHeight : ch ) ;
+ width = ( that._hasScroll( ce, "left" ) ? ce.scrollWidth : cw );
+ height = ( that._hasScroll( ce ) ? ce.scrollHeight : ch );
that.parentData = {
element: ce,
@@ -1195,4 +1213,4 @@ $.ui.plugin.add( "resizable", "grid", {
return $.ui.resizable;
-} ) );
+} );
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Resizable 1.12.1
+ * jQuery UI Resizable 1.13.0-rc.2
* http://jqueryui.com
*
diff --git a/src/js/_enqueues/vendor/jquery/ui/selectable.js b/src/js/_enqueues/vendor/jquery/ui/selectable.js
index 8c0ebce159..64feccea45 100644
--- a/src/js/_enqueues/vendor/jquery/ui/selectable.js
+++ b/src/js/_enqueues/vendor/jquery/ui/selectable.js
@@ -1,5 +1,5 @@
/*!
* jQuery UI Selectable 1.12.1
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -15,6 +15,8 @@
//>>css.structure: ../../themes/base/selectable.css
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -28,10 +30,11 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.widget( "ui.selectable", $.ui.mouse, {
- version: "1.12.1",
+ version: "1.13.0-rc.2",
options: {
appendTo: "body",
autoRefresh: true,
@@ -182,8 +185,12 @@ return $.widget( "ui.selectable", $.ui.mouse, {
x2 = event.pageX,
y2 = event.pageY;
- if ( x1 > x2 ) { tmp = x2; x2 = x1; x1 = tmp; }
- if ( y1 > y2 ) { tmp = y2; y2 = y1; y1 = tmp; }
+ if ( x1 > x2 ) {
+ tmp = x2; x2 = x1; x1 = tmp;
+ }
+ if ( y1 > y2 ) {
+ tmp = y2; y2 = y1; y1 = tmp;
+ }
this.helper.css( { left: x1, top: y1, width: x2 - x1, height: y2 - y1 } );
this.selectees.each( function() {
@@ -306,4 +313,4 @@ return $.widget( "ui.selectable", $.ui.mouse, {
} );
-} ) );
+} );
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Selectable 1.12.1
+ * jQuery UI Selectable 1.13.0-rc.2
* http://jqueryui.com
*
diff --git a/src/js/_enqueues/vendor/jquery/ui/selectmenu.js b/src/js/_enqueues/vendor/jquery/ui/selectmenu.js
index 0df60c949f..df61b606f8 100644
--- a/src/js/_enqueues/vendor/jquery/ui/selectmenu.js
+++ b/src/js/_enqueues/vendor/jquery/ui/selectmenu.js
@@ -1,5 +1,5 @@
/*!
* jQuery UI Selectmenu 1.12.1
* http://jqueryui.com
*
* Copyright jQuery Foundation and other contributors
@@ -9,9 +9,9 @@
//>>label: Selectmenu
//>>group: Widgets
-// jscs:disable maximumLineLength
+/* eslint-disable max-len */
//>>description: Duplicates and extends the functionality of a native HTML select element, allowing it to be customizable in behavior and appearance far beyond the limitations of a native select.
-// jscs:enable maximumLineLength
+/* eslint-enable max-len */
//>>docs: http://api.jqueryui.com/selectmenu/
//>>demos: http://jqueryui.com/selectmenu/
//>>css.structure: ../../themes/base/core.css
@@ -19,6 +19,8 @@
//>>css.theme: ../../themes/base/theme.css
( function( factory ) {
+ "use strict";
+
if ( typeof define === "function" && define.amd ) {
// AMD. Register as an anonymous module.
@@ -32,10 +34,11 @@
// Browser globals
factory( jQuery );
}
-}( function( $ ) {
+} )( function( $ ) {
+"use strict";
return $.widget( "ui.selectmenu", [ $.ui.formResetMixin, {
- version: "1.12.1",
+ version: "1.13.0-rc.2",
defaultElement: "
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Selectmenu 1.12.1
+ * jQuery UI Selectmenu 1.13.0-rc.2
* http://jqueryui.com
*